@@ -4,7 +4,7 @@ relvars.py -- Flatland DB relational variable definitions
     This file defines all relvars (relational variables) for the Flatland database. In SQL terms,
     this is the schema definition for the database. These relvars are derived from the Flatland domain
     models. To understand all of these relvars and their constraints, it is strongly recommended to consult
-    those xuml class model diagrams and text descriptions for both the Flatland Application and Tablet domain models.
+    those xUML class model diagrams and text descriptions for both the Flatland Application and Tablet domain models.
     See comments, first the Flatland application domain relvars are defined and then the Tablet relvars.
 """
 from sqlalchemy import Table, Column, String, Integer, Boolean, Enum, Float
@@ -13,7 +13,7 @@ from sqlalchemy import ForeignKey, UniqueConstraint, PrimaryKeyConstraint, Forei
 
 def define(db) -> dict:
     """
-    Define all the relvars in the Flatland database.
+    Define all the relvars in the Flatland Database.
 
     :param db: A Flatland database class which provides an Sqlalchemy MetaData attribute
     :return: Dictionary of table name key, table schema value pairs
@@ -49,7 +49,7 @@ def define(db) -> dict:
                                                      Enum('left', 'center', 'right', name='enum_Halign'),
                                                      nullable=False),
                                               ),
-        'connector_layout_specification': Table('connector Layout Specification', db.MetaData,
+        'connector_layout_specification': Table('Connector Layout Specification', db.MetaData,
                                                 Column('Name', String(20), nullable=False, primary_key=True),
                                                 Column('Default stem positions', Integer,
                                                        CheckConstraint('"Default stem positions" > 0' and
@@ -82,7 +82,7 @@ def define(db) -> dict:
                                          ForeignKey('Notation.Name', name='R32_notation'), nullable=False),
                                   PrimaryKeyConstraint('Diagram type', 'Notation', name='I1')
                                   ),
-        'node_type': Table('node Type', db.MetaData,
+        'node_type': Table('Node Type', db.MetaData,
                            Column('Name', String, nullable=False),
                            Column('Diagram type', String, ForeignKey('Diagram Type.Name', name='R15'), nullable=False),
                            Column('About', String, nullable=False),
@@ -102,21 +102,21 @@ def define(db) -> dict:
                                   Column('Pad left', Integer, nullable=False),
                                   Column('Pad right', Integer, nullable=False),
                                   Column('Text style', String(15), nullable=False),
-                                  Column('node type', String, nullable=False),
+                                  Column('Node type', String, nullable=False),
                                   Column('Diagram type', String, nullable=False),
                                   Column('Stack order', Integer, nullable=False),
-                                  PrimaryKeyConstraint('Stack order', 'node type', 'Diagram type', name='I1'),
-                                  UniqueConstraint('Name', 'node type', 'Diagram type', name='I2'),
-                                  ForeignKeyConstraint(('node type', 'Diagram type'),
-                                                       ['node Type.Name', 'node Type.Diagram type'], name='R4')
+                                  PrimaryKeyConstraint('Stack order', 'Node type', 'Diagram type', name='I1'),
+                                  UniqueConstraint('Name', 'Node type', 'Diagram type', name='I2'),
+                                  ForeignKeyConstraint(('Node type', 'Diagram type'),
+                                                       ['Node Type.Name', 'Node Type.Diagram type'], name='R4')
                                   ),
-        'nameable_connector_location': Table('Nameable connector Location', db.MetaData,
+        'nameable_connector_location': Table('Nameable Connector Location', db.MetaData,
                                              Column('Name', String, nullable=False),
                                              Column('Diagram type', String,
                                                     ForeignKey('Diagram Type.Name',name='UR70'), nullable=False),
                                              PrimaryKeyConstraint('Name', 'Diagram type', name='I1'),
                                              ),
-        'connector_type': Table('connector Type', db.MetaData,
+        'connector_type': Table('Connector Type', db.MetaData,
                                 Column('Name', String, nullable=False),
                                 Column('About', String, nullable=False),
                                 Column('Geometry', String, nullable=False),
@@ -124,16 +124,16 @@ def define(db) -> dict:
                                        nullable=False),
                                 PrimaryKeyConstraint('Name', 'Diagram type', name='I1'),
                                 ForeignKeyConstraint(('Name', 'Diagram type'),
-                                                     ['Nameable connector Location.Name',
-                                                      'Nameable connector Location.Diagram type'], name='R70')),
-        'connector_style': Table('connector Style', db.MetaData,
-                                 Column('connector type', String, nullable=False),
+                                                     ['Nameable Connector Location.Name',
+                                                      'Nameable Connector Location.Diagram type'], name='R70')),
+        'connector_style': Table('Connector Style', db.MetaData,
+                                 Column('Connector type', String, nullable=False),
                                  Column('Diagram type', String, nullable=False),
                                  Column('Notation', String, nullable=False),
                                  Column('Stroke', String, nullable=False),
-                                 PrimaryKeyConstraint('connector type', 'Diagram type', 'Notation', name='I1'),
-                                 ForeignKeyConstraint(('connector type', 'Diagram type'),
-                                                      ['connector Type.Name', 'connector Type.Diagram type'],
+                                 PrimaryKeyConstraint('Connector type', 'Diagram type', 'Notation', name='I1'),
+                                 ForeignKeyConstraint(('Connector type', 'Diagram type'),
+                                                      ['Connector Type.Name', 'Connector Type.Diagram type'],
                                                       name='R60_connector_type'),
                                  ForeignKeyConstraint(('Notation', 'Diagram type'),
                                                       ['Diagram Notation.Notation', 'Diagram Notation.Diagram type'],
@@ -143,17 +143,17 @@ def define(db) -> dict:
                            Column('Name', String, nullable=False),
                            Column('About', String, nullable=False),
                            Column('Diagram type', String, nullable=False),
-                           Column('connector type', String, nullable=False),
+                           Column('Connector type', String, nullable=False),
                            Column('Minimum length', Integer, nullable=False),
                            Column('Geometry', Enum('fixed', 'hanging', 'free', name='enum_Geometry'), nullable=False),
                            PrimaryKeyConstraint('Name', 'Diagram type', name='I1'),
-                           ForeignKeyConstraint(('connector type', 'Diagram type'),
-                                                ['connector Type.Name', 'connector Type.Diagram type'], name='R59'),
+                           ForeignKeyConstraint(('Connector type', 'Diagram type'),
+                                                ['Connector Type.Name', 'Connector Type.Diagram type'], name='R59'),
                            ForeignKeyConstraint(('Name', 'Diagram type'),
-                                                ['Nameable connector Location.Name',
-                                                 'Nameable connector Location.Diagram type'], name='R70')),
+                                                ['Nameable Connector Location.Name',
+                                                 'Nameable Connector Location.Diagram type'], name='R70')),
         'name_spec': Table('Name Spec', db.MetaData,
-                           Column('connector location', String, nullable=False),
+                           Column('Connector location', String, nullable=False),
                            Column('Diagram type', String, nullable=False),
                            Column('Notation', String, nullable=False),
                            Column('Vertical axis buffer', Integer, nullable=False),
@@ -162,14 +162,14 @@ def define(db) -> dict:
                            Column('Horizontal end buffer', Integer, nullable=False),
                            Column('Default name', String, nullable=False),
                            Column('Optional', Boolean, nullable=False),
-                           PrimaryKeyConstraint('connector location', 'Diagram type', 'Notation', name='I1'),
+                           PrimaryKeyConstraint('Connector location', 'Diagram type', 'Notation', name='I1'),
                            ForeignKeyConstraint(('Diagram type', 'Notation'),
                                                 ['Diagram Notation.Diagram type',
                                                  'Diagram Notation.Notation'],
                                                 name='R71_diag_notation'),
-                           ForeignKeyConstraint(('connector location', 'Diagram type'),
-                                                ['Nameable connector Location.Name',
-                                                 'Nameable connector Location.Diagram type'],
+                           ForeignKeyConstraint(('Connector location', 'Diagram type'),
+                                                ['Nameable Connector Location.Name',
+                                                 'Nameable Connector Location.Diagram type'],
                                                 name='R71_conn_location'),
                            ),
         'stem_semantic': Table('Stem Semantic', db.MetaData,
@@ -304,14 +304,14 @@ def define(db) -> dict:
                           Column('Alias', String, primary_key=True),
                           Column('Name', String, unique=True),
                           ),
-        'drawing_type': Table('drawing Type', db.MetaData,
+        'drawing_type': Table('Drawing Type', db.MetaData,
                               Column('Name', String, primary_key=True, nullable=False),
                               ),
         'asset': Table('Asset', db.MetaData,
                        Column('Name', String, nullable=False),
-                       Column('drawing type', String, nullable=False),
+                       Column('Drawing type', String, nullable=False),
                        Column('Form', Enum('shape', 'text', name='enum_Form')),
-                       PrimaryKeyConstraint('Name', 'drawing type', name='I1'),
+                       PrimaryKeyConstraint('Name', 'Drawing type', name='I1'),
                        ),
         'text_style': Table('Text Style', db.MetaData,
                             Column('Name', String, primary_key=True),
@@ -335,44 +335,44 @@ def define(db) -> dict:
                             ),
         'presentation': Table('Presentation', db.MetaData,
                               Column('Name', String, nullable=False),
-                              Column('drawing type', String, ForeignKey('drawing Type.Name', name='R1'),
+                              Column('Drawing type', String, ForeignKey('Drawing Type.Name', name='R1'),
                                      nullable=False),
-                              PrimaryKeyConstraint('Name', 'drawing type', name='I1')
+                              PrimaryKeyConstraint('Name', 'Drawing type', name='I1')
                               ),
         'text_presentation': Table('Text Presentation', db.MetaData,
                                    Column('Asset', String, nullable=False),
                                    Column('Presentation', String, nullable=False),
-                                   Column('drawing type', String, nullable=False),
+                                   Column('Drawing type', String, nullable=False),
                                    Column('Text style', String, nullable=False),
-                                   PrimaryKeyConstraint('Asset', 'Presentation', 'drawing type', name='I1'),
-                                   ForeignKeyConstraint(('Asset', 'drawing type'),
-                                                        ['Asset.Name', 'Asset.drawing type'],
+                                   PrimaryKeyConstraint('Asset', 'Presentation', 'Drawing type', name='I1'),
+                                   ForeignKeyConstraint(('Asset', 'Drawing type'),
+                                                        ['Asset.Name', 'Asset.Drawing type'],
                                                         name='R5_R4_asset'),
-                                   ForeignKeyConstraint(('Presentation', 'drawing type'),
-                                                        ['Presentation.Name', 'Presentation.drawing type'],
+                                   ForeignKeyConstraint(('Presentation', 'Drawing type'),
+                                                        ['Presentation.Name', 'Presentation.Drawing type'],
                                                         name='R5_R4_pstyle'),
                                    ),
         'shape_presentation': Table('Shape Presentation', db.MetaData,
                                     Column('Asset', String, nullable=False),
                                     Column('Presentation', String, nullable=False),
-                                    Column('drawing type', String, nullable=False),
+                                    Column('Drawing type', String, nullable=False),
                                     Column('Line style', String, nullable=False),
-                                    PrimaryKeyConstraint('Asset', 'Presentation', 'drawing type', name='I1'),
-                                    ForeignKeyConstraint(('Asset', 'drawing type'),
-                                                         ['Asset.Name', 'Asset.drawing type'],
+                                    PrimaryKeyConstraint('Asset', 'Presentation', 'Drawing type', name='I1'),
+                                    ForeignKeyConstraint(('Asset', 'Drawing type'),
+                                                         ['Asset.Name', 'Asset.Drawing type'],
                                                          name='R5_R4_asset'),
-                                    ForeignKeyConstraint(('Presentation', 'drawing type'),
-                                                         ['Presentation.Name', 'Presentation.drawing type'],
+                                    ForeignKeyConstraint(('Presentation', 'Drawing type'),
+                                                         ['Presentation.Name', 'Presentation.Drawing type'],
                                                          name='R5_R4_pstyle'),
                                     ),
         'closed_shape_fill': Table('Closed Shape Fill', db.MetaData,
                                    Column('Asset', String, nullable=False),
                                    Column('Presentation', String, nullable=False),
-                                   Column('drawing type', String, nullable=False),
+                                   Column('Drawing type', String, nullable=False),
                                    Column('Fill', String, ForeignKey('Color.Name', name='R19_color'), nullable=False),
-                                   PrimaryKeyConstraint('Asset', 'Presentation', 'drawing type', name='I1'),
-                                   ForeignKeyConstraint(('Asset', 'Presentation', 'drawing type'),
+                                   PrimaryKeyConstraint('Asset', 'Presentation', 'Drawing type', name='I1'),
+                                   ForeignKeyConstraint(('Asset', 'Presentation', 'Drawing type'),
                                                         ['Shape Presentation.Asset', 'Shape Presentation.Presentation',
-                                                         'Shape Presentation.drawing type'], name='R19_shape_pres')
+                                                         'Shape Presentation.Drawing type'], name='R19_shape_pres')
                                    ),
     }
